npstructures.raggedshape.RaggedView
===================================

.. currentmodule:: npstructures.raggedshape

.. autoclass:: RaggedView

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RaggedView.__init__
      ~RaggedView.empty_rows_removed
      ~RaggedView.get_flat_indices
      ~RaggedView.get_shape
      ~RaggedView.index_array
      ~RaggedView.ravel_multi_index
      ~RaggedView.unravel_multi_index
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RaggedView.ends
      ~RaggedView.lengths
      ~RaggedView.n_rows
      ~RaggedView.starts
   
   